summaryrefslogtreecommitdiff
path: root/build
diff options
context:
space:
mode:
authorMichael J. Chudobiak <mjc@avtechpulse.com>2012-07-19 09:10:22 -0400
committerMichael J. Chudobiak <mjc@avtechpulse.com>2012-07-19 09:10:22 -0400
commit3e81b648cfb865117b3b434029a549b2672ed5bc (patch)
tree82821a191ecc258de67393e7b7f862b501cf9275 /build
parent50506ef3771ce833d76cf29a16d5f1acc288453e (diff)
link libraries properly
Diffstat (limited to 'build')
-rw-r--r--build/Makefile8
-rw-r--r--build/cmake_install.cmake6
2 files changed, 7 insertions, 7 deletions
diff --git a/build/Makefile b/build/Makefile
index e10303e..b8e7243 100644
--- a/build/Makefile
+++ b/build/Makefile
@@ -39,10 +39,10 @@ RM = /usr/bin/cmake -E remove -f
CMAKE_EDIT_COMMAND = /usr/bin/ccmake
# The top-level source directory on which CMake was run.
-CMAKE_SOURCE_DIR = /fileserver2/home/mjc/git/Instrument
+CMAKE_SOURCE_DIR = /fileserver2/home/mjclab2/git/Instrument
# The top-level build directory on which CMake was run.
-CMAKE_BINARY_DIR = /fileserver2/home/mjc/git/Instrument/build
+CMAKE_BINARY_DIR = /fileserver2/home/mjclab2/git/Instrument/build
#=============================================================================
# Targets provided globally by CMake.
@@ -69,9 +69,9 @@ rebuild_cache/fast: rebuild_cache
# The main all target
all: cmake_check_build_system
- $(CMAKE_COMMAND) -E cmake_progress_start /fileserver2/home/mjc/git/Instrument/build/CMakeFiles /fileserver2/home/mjc/git/Instrument/build/CMakeFiles/progress.marks
+ $(CMAKE_COMMAND) -E cmake_progress_start /fileserver2/home/mjclab2/git/Instrument/build/CMakeFiles /fileserver2/home/mjclab2/git/Instrument/build/CMakeFiles/progress.marks
$(MAKE) -f CMakeFiles/Makefile2 all
- $(CMAKE_COMMAND) -E cmake_progress_start /fileserver2/home/mjc/git/Instrument/build/CMakeFiles 0
+ $(CMAKE_COMMAND) -E cmake_progress_start /fileserver2/home/mjclab2/git/Instrument/build/CMakeFiles 0
.PHONY : all
# The main clean target
diff --git a/build/cmake_install.cmake b/build/cmake_install.cmake
index aac7ddf..dd923b5 100644
--- a/build/cmake_install.cmake
+++ b/build/cmake_install.cmake
@@ -1,4 +1,4 @@
# Install script for directory: /fileserver2/home/mjc/git/Instrument
# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
@@ -38,7 +38,7 @@ ELSE(CMAKE_INSTALL_COMPONENT)
SET(CMAKE_INSTALL_MANIFEST "install_manifest.txt")
ENDIF(CMAKE_INSTALL_COMPONENT)
-FILE(WRITE "/fileserver2/home/mjc/git/Instrument/build/${CMAKE_INSTALL_MANIFEST}" "")
+FILE(WRITE "/fileserver2/home/mjclab2/git/Instrument/build/${CMAKE_INSTALL_MANIFEST}" "")
FOREACH(file ${CMAKE_INSTALL_MANIFEST_FILES})
- FILE(APPEND "/fileserver2/home/mjc/git/Instrument/build/${CMAKE_INSTALL_MANIFEST}" "${file}\n")
+ FILE(APPEND "/fileserver2/home/mjclab2/git/Instrument/build/${CMAKE_INSTALL_MANIFEST}" "${file}\n")
ENDFOREACH(file)
@@ -1,4 +1,4 @@
-# Install script for directory: /fileserver2/home/mjc/git/Instrument
+# Install script for directory: /fileserver2/home/mjclab2/git/Instrument
# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)